
RELEASE_VERSION='0.3.625707397'
BUILD_DATE='Mon Aug 29 16:04:20 UTC 2022'
BUILD_MACHINE_INFO='Linux runner-yxfxmkoy-project-28359933-concurrent-0zbg22 5.4.181-99.354.amzn2.x86_64 #1 SMP Wed Mar 2 18:50:46 UTC 2022 x86_64 GNU/Linux'
GITLAB_CI_JOB_ID='2948899918'
GIT_COMMIT_SHA='01276ec59f787345bc9f67d6e3d79a792635c664'
GIT_BRANCH='main'
